from setuptools import setup, find_packages
"""<https://packaging.python.org/guides/distributing-packages-using-setuptools/>"""
"""<https://blog.csdn.net/reyoung1110/article/details/7594171?utm_source=blogxgwz3>"""
setup(
    name='novelsys',
    # description='managed',
    version='0.0.0.0.0.0.0.0a0.dev20221014',
    packages=find_packages(),
    url=' ',
    maintainer=' ',
    maintainer_email=' ',
    # <https://packaging.python.org/guides/distributing-packages-using-setuptools/#python-requires>
    python_requires='~=3.6',
    # <https://pypi.org/classifiers/>
    classifiers=[
        "Development Status :: 1 - Planning",
        # "Environment :: Console",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",

    ]
)
